@@ -41,7 +41,7 @@ typedef enum /*< skip,prefix=XFDASHBOARD_PLUGIN_STATE >*/
 {
 	XFDASHBOARD_PLUGIN_STATE_NONE=0,
 	XFDASHBOARD_PLUGIN_STATE_INITIALIZED,
-	XFDASHBOARD_PLUGIN_STATE_ENABLED,
+	XFDASHBOARD_PLUGIN_STATE_ENABLED
 } XfdashboardPluginState;
 
 
@@ -56,18 +56,18 @@ struct _XfdashboardPluginPrivate
 	gchar						*author;
 	gchar						*copyright;
 	gchar						*license;
-
-	gchar						*configPath;
-	gchar						*cachePath;
-	gchar						*dataPath;
+	XfdashboardPluginSettings	*settings;
 
 	/* Instance related */
 	gchar						*filename;
+	gboolean					didLoad;
 	GModule						*module;
 	void 						(*initialize)(XfdashboardPlugin *self);
 	XfdashboardPluginState		state;
 	gchar						*lastLoadingError;
 
+	gpointer					userData;
+	GDestroyNotify				userDataDestroyCallback;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE(XfdashboardPlugin,
@@ -89,9 +89,7 @@ enum
 	PROP_COPYRIGHT,
 	PROP_LICENSE,
 
-	PROP_CONFIG_PATH,
-	PROP_CACHE_PATH,
-	PROP_DATA_PATH,
+	PROP_SETTINGS,
 
 	PROP_LAST
 };
@@ -118,7 +116,7 @@ static guint XfdashboardPluginSignals[SIGNAL_LAST]={ 0, };
 /* Get display name for XFDASHBOARD_PLUGIN_STATE_* enum values */
 static const gchar* _xfdashboard_plugin_get_plugin_state_value_name(XfdashboardPluginState inState)
 {
-	g_return_val_if_fail(inState>XFDASHBOARD_PLUGIN_STATE_ENABLED, NULL);
+	g_return_val_if_fail(inState<=XFDASHBOARD_PLUGIN_STATE_ENABLED, NULL);
 
 	/* Lookup name for value and return it */
 	switch(inState)
@@ -177,54 +175,6 @@ static void _xfdashboard_plugin_set_filename(XfdashboardPlugin *self, const gcha
 	}
 }
 
-/* Update special paths for this plugin */
-static gboolean _xfdashboard_plugin_update_special_paths(XfdashboardPlugin *self)
-{
-	XfdashboardPluginPrivate		*priv;
-
-	g_return_val_if_fail(XFDASHBOARD_IS_PLUGIN(self), FALSE);
-
-	priv=self->priv;
-
-	/* Check that ID of plugin is set */
-	if(!priv->id)
-	{
-		g_critical("Cannot get path for plugin at %s", priv->filename);
-		return(FALSE);
-	}
-
-	/* Freeze notification */
-	g_object_freeze_notify(G_OBJECT(self));
-
-	/* Update paths of this plugin */
-	if(priv->configPath)
-	{
-		g_free(priv->configPath);
-		priv->configPath=NULL;
-	}
-	priv->configPath=g_build_filename(g_get_user_config_dir(), "xfdashboard", priv->id, NULL);
-
-	if(priv->cachePath)
-	{
-		g_free(priv->cachePath);
-		priv->cachePath=NULL;
-	}
-	priv->cachePath=g_build_filename(g_get_user_cache_dir(), "xfdashboard", priv->id, NULL);
-
-	if(priv->dataPath)
-	{
-		g_free(priv->dataPath);
-		priv->dataPath=NULL;
-	}
-	priv->dataPath=g_build_filename(g_get_user_data_dir(), "xfdashboard", priv->id, NULL);
-
-	/* Thaw notification */
-	g_object_thaw_notify(G_OBJECT(self));
-
-	/* Updating paths was successful */
-	return(TRUE);
-}
-
 /* Set ID for plugin */
 static void _xfdashboard_plugin_set_id(XfdashboardPlugin *self, const gchar *inID)
 {
@@ -246,9 +196,6 @@ static void _xfdashboard_plugin_set_id(XfdashboardPlugin *self, const gchar *inI
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardPluginProperties[PROP_ID]);
-
-		/* When ID changes then also paths of this plugin change */
-		_xfdashboard_plugin_update_special_paths(self);
 	}
 }
 
@@ -414,6 +361,65 @@ static void _xfdashboard_plugin_set_license(XfdashboardPlugin *self, const gchar
 	}
 }
 
+/* Set plugin settings object for plugin */
+static void _xfdashboard_plugin_set_settings(XfdashboardPlugin *self, XfdashboardPluginSettings *inSettings)
+{
+	XfdashboardPluginPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_PLUGIN(self));
+	g_return_if_fail(XFDASHBOARD_IS_PLUGIN_SETTINGS(inSettings));
+	g_return_if_fail(self->priv->settings==NULL);
+	g_return_if_fail(self->priv->state==XFDASHBOARD_PLUGIN_STATE_NONE);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(inSettings!=priv->settings)
+	{
+		/* Set value */
+		if(priv->settings)
+		{
+			g_object_unref(priv->settings);
+			priv->settings=NULL;
+		}
+
+		if(inSettings)
+		{
+			priv->settings=g_object_ref(inSettings);
+		}
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardPluginProperties[PROP_SETTINGS]);
+	}
+}
+
+/* Destroy user data */
+static void _xfdashboard_plugin_destroy_user_data(XfdashboardPlugin *self)
+{
+	XfdashboardPluginPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_PLUGIN(self));
+
+	priv=self->priv;
+
+	/* Check if user data is set and call its destruction callback function
+	 * if it was set also.
+	 */
+	if(priv->userData)
+	{
+		/* Call destruction callback function with user data if available */
+		if(priv->userDataDestroyCallback)
+		{
+			(priv->userDataDestroyCallback)(priv->userData);
+		}
+
+		/* Unset user data and destruction callback */
+		priv->userData=NULL;
+		priv->userDataDestroyCallback=NULL;
+	}
+}
+
+
 /* IMPLEMENTATION: GTypeModule */
 
 /* Load and initialize plugin */
@@ -454,7 +460,7 @@ static gboolean _xfdashboard_plugin_load(GTypeModule *inModule)
 	if(priv->state!=XFDASHBOARD_PLUGIN_STATE_NONE)
 	{
 		priv->lastLoadingError=
-			g_strdup_printf("Bad state '%s' - expected '%s",
+			g_strdup_printf("Bad state '%s' - expected '%s'",
 							_xfdashboard_plugin_get_plugin_state_value_name(priv->state),
 							_xfdashboard_plugin_get_plugin_state_value_name(XFDASHBOARD_PLUGIN_STATE_NONE));
 		return(FALSE);
@@ -590,7 +596,7 @@ static void _xfdashboard_plugin_unload(GTypeModule *inModule)
 		priv->module=NULL;
 	}
 
-	/* Set state of plugin */
+	/* Set state of plugin to uninitialzed */
 	priv->state=XFDASHBOARD_PLUGIN_STATE_NONE;
 }
 
@@ -602,6 +608,9 @@ static void _xfdashboard_plugin_dispose(GObject *inObject)
 	XfdashboardPlugin			*self=XFDASHBOARD_PLUGIN(inObject);
 	XfdashboardPluginPrivate	*priv=self->priv;
 
+	/* First of all destroy user data as long as this object was not disposed */
+	_xfdashboard_plugin_destroy_user_data(self);
+
 	/* Release allocated resources */
 	if(priv->module)
 	{
@@ -650,22 +659,10 @@ static void _xfdashboard_plugin_dispose(GObject *inObject)
 		priv->license=NULL;
 	}
 
-	if(priv->configPath)
+	if(priv->settings)
 	{
-		g_free(priv->configPath);
-		priv->configPath=NULL;
-	}
-
-	if(priv->cachePath)
-	{
-		g_free(priv->cachePath);
-		priv->cachePath=NULL;
-	}
-
-	if(priv->dataPath)
-	{
-		g_free(priv->dataPath);
-		priv->dataPath=NULL;
+		g_object_unref(priv->settings);
+		priv->settings=NULL;
 	}
 
 	/* Sanity checks that module was unloaded - at least by us */
@@ -717,6 +714,10 @@ static void _xfdashboard_plugin_set_property(GObject *inObject,
 			_xfdashboard_plugin_set_license(self, g_value_get_string(inValue));
 			break;
 
+		case PROP_SETTINGS:
+			_xfdashboard_plugin_set_settings(self, g_value_get_object(inValue));
+			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(inObject, inPropID, inSpec);
 			break;
@@ -765,16 +766,8 @@ static void _xfdashboard_plugin_get_property(GObject *inObject,
 			g_value_set_string(outValue, priv->license);
 			break;
 
-		case PROP_CONFIG_PATH:
-			g_value_set_string(outValue, priv->configPath);
-			break;
-
-		case PROP_CACHE_PATH:
-			g_value_set_string(outValue, priv->cachePath);
-			break;
-
-		case PROP_DATA_PATH:
-			g_value_set_string(outValue, priv->dataPath);
+		case PROP_SETTINGS:
+			g_value_set_object(outValue, priv->settings);
 			break;
 
 		default:
@@ -801,6 +794,11 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 	gobjectClass->dispose=_xfdashboard_plugin_dispose;
 
 	/* Define properties */
+	/**
+	 * XfdashboardPlugin:filename:
+	 *
+	 * The path and file name of this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_FILENAME]=
 		g_param_spec_string("filename",
 							"File name",
@@ -808,6 +806,11 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
 
+	/**
+	 * XfdashboardPlugin:id:
+	 *
+	 * The unique ID of this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_ID]=
 		g_param_spec_string("id",
 							"ID",
@@ -815,6 +818,12 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
 
+	/**
+	 * XfdashboardPlugin:flags:
+	 *
+	 * None, one or more flags of type #XfdashboardPluginFlag defining behaviour
+	 * of this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_FLAGS]=
 		g_param_spec_flags("flags",
 							"Flags",
@@ -823,6 +832,11 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							XFDASHBOARD_PLUGIN_FLAG_NONE,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+	/**
+	 * XfdashboardPlugin:name:
+	 *
+	 * The name of this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_NAME]=
 		g_param_spec_string("name",
 							"name",
@@ -830,6 +844,11 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+	/**
+	 * XfdashboardPlugin:description:
+	 *
+	 * The description for this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_DESCRIPTION]=
 		g_param_spec_string("description",
 							"Description",
@@ -837,6 +856,11 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+	/**
+	 * XfdashboardPlugin:author:
+	 *
+	 * The author of this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_AUTHOR]=
 		g_param_spec_string("author",
 							"Author",
@@ -844,6 +868,11 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+	/**
+	 * XfdashboardPlugin:copyright:
+	 *
+	 * The copyright message of this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_COPYRIGHT]=
 		g_param_spec_string("copyright",
 							"Copyright",
@@ -851,6 +880,11 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+	/**
+	 * XfdashboardPlugin:license:
+	 *
+	 * The license of this plugin.
+	 */
 	XfdashboardPluginProperties[PROP_LICENSE]=
 		g_param_spec_string("license",
 							"License",
@@ -858,30 +892,28 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
-	XfdashboardPluginProperties[PROP_CONFIG_PATH]=
-		g_param_spec_string("config-path",
-							"Config path",
-							"The base path to configuration files of this plugin",
-							NULL,
-							G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
-
-	XfdashboardPluginProperties[PROP_CACHE_PATH]=
-		g_param_spec_string("cache-path",
-							"Cache path",
-							"The base path to cache files of this plugin",
-							NULL,
-							G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
-
-	XfdashboardPluginProperties[PROP_DATA_PATH]=
-		g_param_spec_string("data-path",
-							"Data path",
-							"The base path to data files of this plugin",
-							NULL,
-							G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+	/**
+	 * XfdashboardPlugin:settings:
+	 *
+	 * The settings object of type #XfdashboardPluginSettings for this plugin.
+	 */
+	XfdashboardPluginProperties[PROP_SETTINGS]=
+		g_param_spec_object("settings",
+								"Settings",
+								"The plugin settings object of this plugin",
+								XFDASHBOARD_TYPE_PLUGIN_SETTINGS,
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardPluginProperties);
 
 	/* Define signals */
+	/**
+	 * XfdashboardPlugin::enable:
+	 * @self: The plugin
+	 *
+	 * The ::enable signal is an action and when emitted it causes the plugin
+	 * at @self to get enabled.
+	 */
 	XfdashboardPluginSignals[ACTION_ENABLE]=
 		g_signal_new("enable",
 						G_TYPE_FROM_CLASS(klass),
@@ -893,6 +925,13 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 						G_TYPE_NONE,
 						0);
 
+	/**
+	 * XfdashboardPlugin::disable:
+	 * @self: The plugin
+	 *
+	 * The ::disable signal is an action and when emitted it causes the plugin
+	 * at @self to get disabled.
+	 */
 	XfdashboardPluginSignals[ACTION_DISABLE]=
 		g_signal_new("disable",
 						G_TYPE_FROM_CLASS(klass),
@@ -904,6 +943,16 @@ static void xfdashboard_plugin_class_init(XfdashboardPluginClass *klass)
 						G_TYPE_NONE,
 						0);
 
+	/**
+	 * XfdashboardPlugin::configure:
+	 * @self: The plugin
+	 *
+	 * The ::configure signal is an action and when emitted it will let the plugin
+	 * at @self create any kind of object, usually an object derived from #GtkWidget,
+	 * to configure the settings of this plugin.
+	 *
+	 * Return value: A #GObject to use to configure this plugin.
+	 */
 	XfdashboardPluginSignals[ACTION_CONFIGURE]=
 		g_signal_new("configure",
 						G_TYPE_FROM_CLASS(klass),
@@ -927,10 +976,13 @@ static void xfdashboard_plugin_init(XfdashboardPlugin *self)
 
 	/* Set up default values */
 	priv->filename=NULL;
+	priv->didLoad=FALSE;
 	priv->module=NULL;
 	priv->initialize=NULL;
 	priv->state=XFDASHBOARD_PLUGIN_STATE_NONE;
 	priv->lastLoadingError=NULL;
+	priv->userData=NULL;
+	priv->userDataDestroyCallback=NULL;
 
 	priv->id=NULL;
 	priv->flags=XFDASHBOARD_PLUGIN_FLAG_NONE;
@@ -939,10 +991,7 @@ static void xfdashboard_plugin_init(XfdashboardPlugin *self)
 	priv->author=NULL;
 	priv->copyright=NULL;
 	priv->license=NULL;
-
-	priv->configPath=NULL;
-	priv->cachePath=NULL;
-	priv->dataPath=NULL;
+	priv->settings=NULL;
 }
 
 
@@ -956,7 +1005,24 @@ GQuark xfdashboard_plugin_error_quark(void)
 
 /* IMPLEMENTATION: Public API */
 
-/* Create an uninitialized plugin */
+/**
+ * xfdashboard_plugin_new:
+ *
+ * Creates a plugin instance of type #XfdashboardPlugin which will be loaded
+ * from path at @inPluginFilename. The plugin ID is retrieved from the basename
+ * of plugin's path, i.e. the file name without the absolute path and without
+ * file extension.
+ *
+ * The plugin instance created is loaded and initialized but disabled by
+ * default. This has to be done after successful creation by calling
+ * xfdashboard_plugin_enable().
+ *
+ * In case of errors %NULL will be returned and the error is set at
+ * @outError.
+ *
+ * Return value: (transfer full): The disabled plugin instance of
+ *   #XfdashboardPlugin. Use g_object_unref() when done.
+ */
 XfdashboardPlugin* xfdashboard_plugin_new(const gchar *inPluginFilename, GError **outError)
 {
 	GObject			*plugin;
@@ -964,7 +1030,7 @@ XfdashboardPlugin* xfdashboard_plugin_new(const gchar *inPluginFilename, GError
 	gchar			*pluginID;
 
 	g_return_val_if_fail(inPluginFilename && *inPluginFilename, NULL);
-	g_return_val_if_fail(outError==NULL || *outError==NULL, FALSE);
+	g_return_val_if_fail(outError==NULL || *outError==NULL, NULL);
 
 	/* Get plugin ID from filename */
 	pluginBasename=g_filename_display_basename(inPluginFilename);
@@ -1030,7 +1096,6 @@ XfdashboardPlugin* xfdashboard_plugin_new(const gchar *inPluginFilename, GError
 		 * use it (via g_type_module_use). As describe in GObject documentation
 		 * the object must not be unreffed via g_object_unref() but we also should
 		 * not call g_type_module_unuse() because loading failed and the reference
-		 * counter was not increased.
 		 */
 		return(NULL);
 	}
@@ -1043,7 +1108,14 @@ XfdashboardPlugin* xfdashboard_plugin_new(const gchar *inPluginFilename, GError
 	return(XFDASHBOARD_PLUGIN(plugin));
 }
 
-/* Get ID of plugin */
+/**
+ * xfdashboard_plugin_get_id:
+ * @self: A #XfdashboardPlugin
+ *
+ * Retrieve the ID of plugin at @self.
+ *
+ * Return value: The plugin ID
+ */
 const gchar* xfdashboard_plugin_get_id(XfdashboardPlugin *self)
 {
 	g_return_val_if_fail(XFDASHBOARD_IS_PLUGIN(self), NULL);
@@ -1051,7 +1123,14 @@ const gchar* xfdashboard_plugin_get_id(XfdashboardPlugin *self)
 	return(self->priv->id);
 }
 
-/* Get flags of plugin */
+/**
+ * xfdashboard_plugin_get_flags:
+ * @self: A #XfdashboardPlugin
+ *
+ * Retrieve the flags associated with plugin at @self.
+ *
+ * Return value: The flags of type #XfdashboardPluginFlag
+ */
 XfdashboardPluginFlag xfdashboard_plugin_get_flags(XfdashboardPlugin *self)
 {
 	g_return_val_if_fail(XFDASHBOARD_IS_PLUGIN(self), XFDASHBOARD_PLUGIN_FLAG_NONE);
@@ -1060,6 +1139,17 @@ XfdashboardPluginFlag xfdashboard_plugin_get_flags(XfdashboardPlugin *self)
 }
 
 /* Set plugin information */
+
+/**
+ * xfdashboard_plugin_set_info:
+ * @self: A #XfdashboardPlugin
+ * @inFirstPropertyName: The name of the first informational property to set
+ * @...: The value for the first informational property to set, followed
+ *   optionally by more name/value pairs, followed by NULL
+ *
+ * Sets informational properties for plugin at @self. The plugin must not be
+ * initialized or enabled.
+ */
 void xfdashboard_plugin_set_info(XfdashboardPlugin *self,
 									const gchar *inFirstPropertyName, ...)
 {
@@ -1073,9 +1163,10 @@ void xfdashboard_plugin_set_info(XfdashboardPlugin *self,
 	/* Check that plugin is not initialized already */
 	if(priv->state!=XFDASHBOARD_PLUGIN_STATE_NONE)
 	{
-		g_critical("Setting plugin information for plugin '%s' at path '%s' failed: Plugin is already initialized",
+		g_critical("Setting plugin information for plugin '%s' at path '%s' failed: Plugin has state '%s'",
 					priv->id ? priv->id : "Unknown",
-					priv->filename);
+					priv->filename,
+					_xfdashboard_plugin_get_plugin_state_value_name(priv->state));
 		return;
 	}
 
@@ -1085,7 +1176,14 @@ void xfdashboard_plugin_set_info(XfdashboardPlugin *self,
 	va_end(args);
 }
 
-/* Get enabled state of plugin */
+/**
+ * xfdashboard_plugin_is_enabled:
+ * @self: A #XfdashboardPlugin
+ *
+ * Retrieve if plugin at @self was successfully loaded and enabled.
+ *
+ * Return value: %TRUE if plugin was enabled, otherwise %FALSE
+ */
 gboolean xfdashboard_plugin_is_enabled(XfdashboardPlugin *self)
 {
 	XfdashboardPluginPrivate		*priv;
@@ -1101,7 +1199,12 @@ gboolean xfdashboard_plugin_is_enabled(XfdashboardPlugin *self)
 	return(FALSE);
 }
 
-/* Enable plugin */
+/**
+ * xfdashboard_plugin_enable:
+ * @self: A #XfdashboardPlugin
+ *
+ * Enables the plugin at @self.
+ */
 void xfdashboard_plugin_enable(XfdashboardPlugin *self)
 {
 	XfdashboardPluginPrivate		*priv;
@@ -1141,7 +1244,12 @@ void xfdashboard_plugin_enable(XfdashboardPlugin *self)
 	priv->state=XFDASHBOARD_PLUGIN_STATE_ENABLED;
 }
 
-/* Disable plugin */
+/**
+ * xfdashboard_plugin_disable:
+ * @self: A #XfdashboardPlugin
+ *
+ * Disables the plugin at @self.
+ */
 void xfdashboard_plugin_disable(XfdashboardPlugin *self)
 {
 	XfdashboardPluginPrivate		*priv;
@@ -1170,26 +1278,81 @@ void xfdashboard_plugin_disable(XfdashboardPlugin *self)
 	priv->state=XFDASHBOARD_PLUGIN_STATE_INITIALIZED;
 }
 
-/* Get base path to configuration files of this plugin */
-const gchar* xfdashboard_plugin_get_config_path(XfdashboardPlugin *self)
+/**
+ * xfdashboard_plugin_get_user_data:
+ * @self: A #XfdashboardPlugin
+ *
+ * Retrieve the user data of plugin at @self.
+ *
+ * Return value: The user data
+ */
+gpointer xfdashboard_plugin_get_user_data(XfdashboardPlugin *self)
 {
 	g_return_val_if_fail(XFDASHBOARD_IS_PLUGIN(self), NULL);
 
-	return(self->priv->configPath);
+	return(self->priv->userData);
 }
 
-/* Get base path to cache files of this plugin */
-const gchar* xfdashboard_plugin_get_cache_path(XfdashboardPlugin *self)
+/**
+ * xfdashboard_plugin_set_user_data:
+ * @self: A #XfdashboardPlugin
+ * @inUserData: The user data to set
+ *
+ * Sets the user data @inUserData at plugin @self but without a callback
+ * function to call when user data is destroyed.
+ */
+void xfdashboard_plugin_set_user_data(XfdashboardPlugin *self, gpointer inUserData)
+{
+	xfdashboard_plugin_set_user_data_full(self, inUserData, NULL);
+}
+
+/**
+ * xfdashboard_plugin_set_user_data_full:
+ * @self: A #XfdashboardPlugin
+ * @inUserData: The user data to set
+ * @inDestroyCallback: The callback to call when destructing user data
+ *
+ * Sets the user data at @inUserData at plugin at @self with a callback
+ * function at @inDestroyCallback which is called when user data will be
+ * destroyed. The destruction callback will always be set even if user
+ * data did not change. The current user data at plugin at @self will be
+ * destroyed with the current destruction callback if user data changes
+ * before the new user data at @inUserData and the new destruction
+ * callback at @inDestroyCallback is set.
+ */
+void xfdashboard_plugin_set_user_data_full(XfdashboardPlugin *self, gpointer inUserData, GDestroyNotify inDestroyCallback)
+{
+	XfdashboardPluginPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_PLUGIN(self));
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(priv->userData!=inUserData)
+	{
+		/* Destroy old user data */
+		_xfdashboard_plugin_destroy_user_data(self);
+
+		/* Set value */
+		priv->userData=inUserData;
+	}
+
+	/* Set new destroy callback functions */
+	priv->userDataDestroyCallback=inDestroyCallback;
+}
+
+/**
+ * xfdashboard_plugin_get_settings:
+ * @self: A #XfdashboardPlugin
+ *
+ * Retrieve the settings object of plugin at @self.
+ *
+ * Return value: The setting object of plugin
+ */
+XfdashboardPluginSettings* xfdashboard_plugin_get_settings(XfdashboardPlugin *self)
 {
 	g_return_val_if_fail(XFDASHBOARD_IS_PLUGIN(self), NULL);
 
-	return(self->priv->cachePath);
-}
-
-/* Get base path to data files of this plugin */
-const gchar* xfdashboard_plugin_get_data_path(XfdashboardPlugin *self)
-{
-	g_return_val_if_fail(XFDASHBOARD_IS_PLUGIN(self), NULL);
-
-	return(self->priv->dataPath);
+	return(self->priv->settings);
 }
