@@ -32,6 +32,8 @@
 #include <glib.h>
 #include <gio/gio.h>
 
+#include <libxfdashboard/application.h>
+#include <libxfdashboard/settings.h>
 #include <libxfdashboard/compat.h>
 #include <libxfdashboard/debug.h>
 
@@ -478,26 +480,49 @@ static gboolean _xfdashboard_theme_load_resources(XfdashboardTheme *self,
 static gchar* _xfdashboard_theme_lookup_path_for_theme(XfdashboardTheme *self,
 														const gchar *inThemeName)
 {
-	gchar				*themeFile;
+	XfdashboardSettings		*settings;
+	const gchar				**searchPaths;
+	gchar					*themeFile;
 
 	g_return_val_if_fail(XFDASHBOARD_IS_THEME(self), FALSE);
 	g_return_val_if_fail(inThemeName!=NULL && *inThemeName!=0, FALSE);
 
 	themeFile=NULL;
 
-	/* Search theme file in given environment variable if set.
-	 * This makes development easier when theme changes are needed
-	 * without changing theme or changing symlinks in any of below
-	 * searched paths.
-	 */
-	if(!themeFile)
-	{
-		const gchar		*envPath;
+	/* Get search path for themes */
+	settings=xfdashboard_application_get_settings(NULL);
+	searchPaths=xfdashboard_settings_get_theme_search_paths(settings);
 
-		envPath=g_getenv("XFDASHBOARD_THEME_PATH");
-		if(envPath)
+	/* Iterate through search paths and look up theme */
+	while(searchPaths && *searchPaths && !themeFile)
+	{
+		/* Restore old behaviour to force a theme path via an environment
+		 * variable but this time with theme search paths. The behaviour
+		 * was to take the provided path and add the theme file without
+		 * any additional subpath like theme name or theme subpath folder.
+		 * If this built path provides the theme file use it directly
+		 * although it might not match the theme name (that is for sure
+		 * as the theme name will not be added to the path built). This
+		 * behaviour makes development easier to test themes without
+		 * changing theme by settings or changing symlinks in any of
+		 * theme searched paths.
+		 */
+		themeFile=g_build_filename(*searchPaths, XFDASHBOARD_THEME_FILE, NULL);
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Trying theme file: %s",
+							themeFile);
+		if(!g_file_test(themeFile, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
 		{
-			themeFile=g_build_filename(envPath, XFDASHBOARD_THEME_FILE, NULL);
+			/* File does not exists so release allocated resources */
+			g_free(themeFile);
+			themeFile=NULL;
+
+			/* Next build theme file path depending on theme name and
+			 * required sub-folders and test for existence.
+			 * If it does exist, keep theme file path. If it does not exist,
+			 * unset theme file path and continue iterating.
+			 */
+			themeFile=g_build_filename(*searchPaths, inThemeName, XFDASHBOARD_THEME_SUBPATH, XFDASHBOARD_THEME_FILE, NULL);
 			XFDASHBOARD_DEBUG(self, THEME,
 								"Trying theme file: %s",
 								themeFile);
@@ -507,57 +532,12 @@ static gchar* _xfdashboard_theme_lookup_path_for_theme(XfdashboardTheme *self,
 				themeFile=NULL;
 			}
 		}
+
+		/* Move iterator to next entry */
+		searchPaths++;
 	}
-
-	/* If file not found search in user's config directory */
-	if(!themeFile)
-	{
-		themeFile=g_build_filename(g_get_user_data_dir(), "themes", inThemeName, XFDASHBOARD_THEME_SUBPATH, XFDASHBOARD_THEME_FILE, NULL);
-		XFDASHBOARD_DEBUG(self, THEME,
-							"Trying theme file: %s",
-							themeFile);
-		if(!g_file_test(themeFile, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
-		{
-			g_free(themeFile);
-			themeFile=NULL;
-		}
-	}
-
-	/* If file not found search in user's home directory */
-	if(!themeFile)
-	{
-		const gchar		*homeDirectory;
-
-		homeDirectory=g_get_home_dir();
-		if(homeDirectory)
-		{
-			themeFile=g_build_filename(homeDirectory, ".themes", inThemeName, XFDASHBOARD_THEME_SUBPATH, XFDASHBOARD_THEME_FILE, NULL);
-			XFDASHBOARD_DEBUG(self, THEME,
-								"Trying theme file: %s",
-								themeFile);
-			if(!g_file_test(themeFile, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
-			{
-				g_free(themeFile);
-				themeFile=NULL;
-			}
-		}
-	}
-
-	/* If file not found search in system-wide paths */
-	if(!themeFile)
-	{
-		themeFile=g_build_filename(PACKAGE_DATADIR, "themes", inThemeName, XFDASHBOARD_THEME_SUBPATH, XFDASHBOARD_THEME_FILE, NULL);
-		XFDASHBOARD_DEBUG(self, THEME,
-							"Trying theme file: %s",
-							themeFile);
-		if(!g_file_test(themeFile, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
-		{
-			g_free(themeFile);
-			themeFile=NULL;
-		}
-	}
-
-	/* If file was found get path contaning file and return it */
+	
+	/* If file was found, get path contaning file and return it */
 	if(themeFile)
 	{
 		gchar			*themePath;
