@@ -39,9 +39,6 @@
 #include <glib/gi18n-lib.h>
 #include <clutter/clutter.h>
 #include <gtk/gtk.h>
-#ifdef XFCONF_LEGACY
-#include <dbus/dbus-glib.h>
-#endif
 #include <gio/gdesktopappinfo.h>
 
 #include <libxfdashboard/stage.h>
@@ -52,25 +49,6 @@
 #include <libxfdashboard/debug.h>
 
 
-/* Gobject type for pointer arrays (GPtrArray) */
-GType xfdashboard_pointer_array_get_type(void)
-{
-	static volatile gsize	type__volatile=0;
-	GType					type;
-
-	if(g_once_init_enter(&type__volatile))
-	{
-#ifdef XFCONF_LEGACY
-		type=dbus_g_type_get_collection("GPtrArray", G_TYPE_VALUE);
-#else
-		type=G_TYPE_PTR_ARRAY;
-#endif
-		g_once_init_leave(&type__volatile, type);
-	}
-
-	return(type__volatile);
-}
-
 /* Callback function for xfdashboard_traverse_actor() to find stage interface
  * used in xfdashboard_notify().
  */
@@ -872,3 +850,27 @@ void xfdashboard_dump_actor(ClutterActor *inActor)
 	 */
 	_xfdashboard_dump_actor_internal(inActor, 1);
 }
+
+/**
+ * xfdashboard_strv_equal:
+ * @inLeft: a %NULL-terminated array of strings
+ * @inRight: another %NULL-terminated array of strings
+ *
+ * Checks if @inLeft and @inRight contain exactly the same elements in exactly 
+ * the same order. Two empty arrays are considered equal. If @inLeft and/or
+ * @inRight are %NULL they are considered empty which is the difference to
+ * @g_strv_equal().
+ *
+ * Returns: %TRUE if @inLeft and @inRight are equal, otherwise %FALSE
+ */
+gboolean xfdashboard_strv_equal(const gchar **inLeft, const gchar **inRight)
+{
+	static const gchar		*empty[]={ NULL };
+
+	/* If any array pointer is NULL, consider them empty */
+	if(!inLeft) inLeft=empty;
+	if(!inRight) inRight=empty;
+
+	/* Now compare them */
+	return(g_strv_equal(inLeft, inRight));
+}
