@@ -38,143 +38,55 @@ G_MODULE_EXPORT void plugin_init(XfdashboardPlugin *self);
 
 /* IMPLEMENTATION: XfdashboardPlugin */
 
-#define CONFIGURATION_MAPPING		"xfdashboard-plugin-hot_corner-configuration-settings"
-
-typedef struct _PluginWidgetSettingsMap		PluginWidgetSettingsMap;
-struct _PluginWidgetSettingsMap
-{
-	XfdashboardHotCornerSettings	*settings;
-	gchar							*property;
-	guint							settingsPropertyChangedSignalID;
-	GCallback						settingsPropertyCallback;
-	GtkWidget						*widget;
-};
-
-typedef void (*PluginWidgetSettingsMapValueChangedCallback)(PluginWidgetSettingsMap *inMapping);
-
 static XfdashboardHotCorner			*hotCorner=NULL;
 
-/* Free mapping data */
-static void _plugin_widget_settings_map_free(PluginWidgetSettingsMap *inData)
-{
-	g_return_if_fail(inData);
-
-	/* Release allocated resources */
-	if(inData->settingsPropertyChangedSignalID) g_signal_handler_disconnect(inData->settings, inData->settingsPropertyChangedSignalID);
-	if(inData->property) g_free(inData->property);
-	if(inData->settings) g_object_unref(inData->settings);
-	g_free(inData);
-}
-
-/* A bound property at settings changed its value so call registered callback handler
- * for the widget.
- */
-static void _plugin_on_widget_settings_map_settings_value_changed(GObject *inObject,
-																	GParamSpec *inSpec,
-																	gpointer inUserData)
-{
-	PluginWidgetSettingsMap							*mapping;
-
-	g_return_if_fail(XFDASHBOARD_IS_HOT_CORNER_SETTINGS(inObject));
-	g_return_if_fail(inUserData);
-
-	mapping=(PluginWidgetSettingsMap*)inUserData;
-
-
-	/* Call callback function */
-	if(mapping->settingsPropertyCallback)
-	{
-		((PluginWidgetSettingsMapValueChangedCallback)mapping->settingsPropertyCallback)(mapping);
-	}
-}
-
-/* Create mapping data and bind to widget */
-static PluginWidgetSettingsMap* _plugin_widget_settings_map_bind(GtkWidget *inWidget,
-																	XfdashboardHotCornerSettings *inSettings,
-																	const gchar *inProperty,
-																	GCallback inCallback)
-{
-	PluginWidgetSettingsMap			*mapping;
-	gchar							*signalName;
-	guint							signalID;
-
-	g_return_val_if_fail(GTK_IS_WIDGET(inWidget), NULL);
-	g_return_val_if_fail(XFDASHBOARD_IS_HOT_CORNER_SETTINGS(inSettings), NULL);
-	g_return_val_if_fail(inProperty && *inProperty, NULL);
-
-	/* Create new mapping */
-	mapping=g_new0(PluginWidgetSettingsMap, 1);
-	if(!mapping)
-	{
-		g_critical("Cannot allocate memory for mapping");
-		return(NULL);
-	}
-
-	/* Connect signal to get notified if value at settings changed */
-	signalName=g_strdup_printf("notify::%s", inProperty);
-	signalID=g_signal_connect(inSettings,
-								signalName,
-								G_CALLBACK(_plugin_on_widget_settings_map_settings_value_changed),
-								mapping);
-	g_free(signalName);
-
-	/* Set up mapping */
-	mapping->settings=g_object_ref(inSettings);
-	mapping->property=g_strdup(inProperty);
-	mapping->settingsPropertyChangedSignalID=signalID;
-	mapping->settingsPropertyCallback=inCallback;
-	mapping->widget=inWidget;
-
-	/* Bind to widget */
-	g_object_set_data_full(G_OBJECT(inWidget),
-							CONFIGURATION_MAPPING,
-							mapping,
-							(GDestroyNotify)_plugin_widget_settings_map_free);
-
-	/* Return mapping */
-	return(mapping);
-}
-
 /* Value for activation corner was changed at widget */
-static void _plugin_on_corner_widget_value_changed(GtkComboBox *inComboBox,
+static void _plugin_on_corner_widget_value_changed(GtkWidget *inWidget,
 													gpointer inUserData,
 													gpointer dummy1,
 													gpointer dummy2)
 {
-	PluginWidgetSettingsMap			*mapping;
+	XfdashboardHotCornerSettings	*settings;
 	GtkTreeModel					*model;
 	GtkTreeIter						iter;
 	gint							value;
 
-	g_return_if_fail(GTK_IS_COMBO_BOX(inComboBox));
-	g_return_if_fail(inUserData);
-
-	mapping=(PluginWidgetSettingsMap*)inUserData;
+	g_return_if_fail(GTK_IS_COMBO_BOX(inWidget));
 
 	/* Get new value from widget */
-	model=gtk_combo_box_get_model(inComboBox);
-	gtk_combo_box_get_active_iter(inComboBox, &iter);
+	model=gtk_combo_box_get_model(GTK_COMBO_BOX(inWidget));
+	gtk_combo_box_get_active_iter(GTK_COMBO_BOX(inWidget), &iter);
 	gtk_tree_model_get(model, &iter, 1, &value, -1);
 
 	/* Store new value at settings */
-	xfdashboard_hot_corner_settings_set_activation_corner(mapping->settings, value);
+	settings=xfdashboard_hot_corner_settings_new();
+	xfdashboard_hot_corner_settings_set_activation_corner(settings, value);
+	g_object_unref(settings);
 }
 
 /* Value for activation corner was changed at settings */
-static void _plugin_on_corner_settings_value_changed(PluginWidgetSettingsMap *inMapping)
+static void _plugin_on_corner_settings_value_changed(GObject *inObject,
+														GParamSpec *inSpec,
+														gpointer inUserData)
 {
+	XfdashboardHotCornerSettings					*settings;
+	GtkComboBox										*widget;
 	XfdashboardHotCornerSettingsActivationCorner	value;
 	guint											modelValue;
 	GtkTreeModel									*model;
 	GtkTreeIter										iter;
 
-	g_return_if_fail(inMapping);
+	g_return_if_fail(XFDASHBOARD_IS_HOT_CORNER_SETTINGS(inObject));
+	g_return_if_fail(GTK_IS_COMBO_BOX(inUserData));
+
+	settings=XFDASHBOARD_HOT_CORNER_SETTINGS(inObject);
+	widget=GTK_COMBO_BOX(inUserData);
 
 	/* Get new value from settings */
-	value=xfdashboard_hot_corner_settings_get_activation_corner(inMapping->settings);
+	value=xfdashboard_hot_corner_settings_get_activation_corner(settings);
 
 	/* Iterate through combo box value and set new value if match is found */
-	model=gtk_combo_box_get_model(GTK_COMBO_BOX(inMapping->widget));
+	model=gtk_combo_box_get_model(widget);
 	if(gtk_tree_model_get_iter_first(model, &iter))
 	{
 		do
@@ -182,7 +94,7 @@ static void _plugin_on_corner_settings_value_changed(PluginWidgetSettingsMap *in
 			gtk_tree_model_get(model, &iter, 1, &modelValue, -1);
 			if(G_UNLIKELY(modelValue==value))
 			{
-				gtk_combo_box_set_active_iter(GTK_COMBO_BOX(inMapping->widget), &iter);
+				gtk_combo_box_set_active_iter(widget, &iter);
 				break;
 			}
 		}
@@ -191,69 +103,83 @@ static void _plugin_on_corner_settings_value_changed(PluginWidgetSettingsMap *in
 }
 
 /* Value for activation radius was changed at widget */
-static void _plugin_on_radius_widget_value_changed(GtkSpinButton *inButton,
+static void _plugin_on_radius_widget_value_changed(GtkWidget *inWidget,
 													gpointer inUserData)
 {
-	PluginWidgetSettingsMap			*mapping;
+	XfdashboardHotCornerSettings	*settings;
 	gint							value;
 
-	g_return_if_fail(GTK_IS_SPIN_BUTTON(inButton));
-	g_return_if_fail(inUserData);
-
-	mapping=(PluginWidgetSettingsMap*)inUserData;
+	g_return_if_fail(GTK_IS_SPIN_BUTTON(inWidget));
 
 	/* Get new value from widget */
-	value=gtk_spin_button_get_value_as_int(inButton);
+	value=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(inWidget));
 
 	/* Store new value at settings */
-	xfdashboard_hot_corner_settings_set_activation_radius(mapping->settings, value);
+	settings=xfdashboard_hot_corner_settings_new();
+	xfdashboard_hot_corner_settings_set_activation_radius(settings, value);
+	g_object_unref(settings);
 }
 
 /* Value for activation radius was changed at settings */
-static void _plugin_on_radius_settings_value_changed(PluginWidgetSettingsMap *inMapping)
+static void _plugin_on_radius_settings_value_changed(GObject *inObject,
+														GParamSpec *inSpec,
+														gpointer inUserData)
 {
+	XfdashboardHotCornerSettings	*settings;
+	GtkSpinButton					*widget;
 	gint							value;
 
-	g_return_if_fail(inMapping);
+	g_return_if_fail(XFDASHBOARD_IS_HOT_CORNER_SETTINGS(inObject));
+	g_return_if_fail(GTK_IS_SPIN_BUTTON(inUserData));
+
+	settings=XFDASHBOARD_HOT_CORNER_SETTINGS(inObject);
+	widget=GTK_SPIN_BUTTON(inUserData);
 
 	/* Get new value from settings */
-	value=xfdashboard_hot_corner_settings_get_activation_radius(inMapping->settings);
+	value=xfdashboard_hot_corner_settings_get_activation_radius(settings);
 
 	/* Set new value at widget */
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(inMapping->widget), value);
+	gtk_spin_button_set_value(widget, value);
 }
 
 /* Value for activation duration was changed at widget */
-static void _plugin_on_duration_widget_value_changed(GtkRange *inRange,
+static void _plugin_on_duration_widget_value_changed(GtkWidget *inWidget,
 														gpointer inUserData)
 {
-	PluginWidgetSettingsMap			*mapping;
+	XfdashboardHotCornerSettings	*settings;
 	gint64							value;
 
-	g_return_if_fail(GTK_IS_RANGE(inRange));
-	g_return_if_fail(inUserData);
-
-	mapping=(PluginWidgetSettingsMap*)inUserData;
+	g_return_if_fail(GTK_IS_RANGE(inWidget));
 
 	/* Get new value from widget */
-	value=gtk_range_get_value(inRange);
+	value=gtk_range_get_value(GTK_RANGE(inWidget));
 
 	/* Store new value at settings */
-	xfdashboard_hot_corner_settings_set_activation_duration(mapping->settings, value);
+	settings=xfdashboard_hot_corner_settings_new();
+	xfdashboard_hot_corner_settings_set_activation_duration(settings, value);
+	g_object_unref(settings);
 }
 
 /* Value for activation duration was changed at settings */
-static void _plugin_on_duration_settings_value_changed(PluginWidgetSettingsMap *inMapping)
+static void _plugin_on_duration_settings_value_changed(GObject *inObject,
+														GParamSpec *inSpec,
+														gpointer inUserData)
 {
+	XfdashboardHotCornerSettings	*settings;
+	GtkRange						*widget;
 	gint64							value;
 
-	g_return_if_fail(inMapping);
+	g_return_if_fail(XFDASHBOARD_IS_HOT_CORNER_SETTINGS(inObject));
+	g_return_if_fail(GTK_IS_SPIN_BUTTON(inUserData));
+
+	settings=XFDASHBOARD_HOT_CORNER_SETTINGS(inObject);
+	widget=GTK_RANGE(inUserData);
 
 	/* Get new value from settings */
-	value=xfdashboard_hot_corner_settings_get_activation_duration(inMapping->settings);
+	value=xfdashboard_hot_corner_settings_get_activation_duration(settings);
 
 	/* Set new value at widget */
-	gtk_range_set_value(GTK_RANGE(inMapping->widget), value);
+	gtk_range_set_value(widget, value);
 }
 
 /* Format value to show activation duration time in milliseconds */
@@ -280,38 +206,99 @@ static gchar* _plugin_on_duration_settings_format_value(GtkScale *inWidget,
 }
 
 /* Value for primary-monitor-only was changed at widget */
-static void _plugin_on_primary_monitor_only_widget_value_changed(GtkToggleButton *inButton,
+static void _plugin_on_primary_monitor_only_widget_value_changed(GtkWidget *inWidget,
 																	gpointer inUserData)
 {
-	PluginWidgetSettingsMap			*mapping;
+	XfdashboardHotCornerSettings	*settings;
 	gboolean						value;
 
-	g_return_if_fail(GTK_IS_TOGGLE_BUTTON(inButton));
-	g_return_if_fail(inUserData);
-
-	mapping=(PluginWidgetSettingsMap*)inUserData;
+	g_return_if_fail(GTK_IS_TOGGLE_BUTTON(inWidget));
 
 	/* Get new value from widget */
-	value=gtk_toggle_button_get_active(inButton);
+	value=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(inWidget));
 
 	/* Store new value at settings */
-	xfdashboard_hot_corner_settings_set_primary_monitor_only(mapping->settings, value);
+	settings=xfdashboard_hot_corner_settings_new();
+	xfdashboard_hot_corner_settings_set_primary_monitor_only(settings, value);
+	g_object_unref(settings);
 }
 
 /* Value for activation duration was changed at settings */
-static void _plugin_on_primary_monitor_only_settings_value_changed(PluginWidgetSettingsMap *inMapping)
+static void _plugin_on_primary_monitor_only_settings_value_changed(GObject *inObject,
+																	GParamSpec *inSpec,
+																	gpointer inUserData)
 {
+	XfdashboardHotCornerSettings	*settings;
+	GtkToggleButton					*widget;
 	gboolean						value;
 
-	g_return_if_fail(inMapping);
+	g_return_if_fail(XFDASHBOARD_IS_HOT_CORNER_SETTINGS(inObject));
+	g_return_if_fail(GTK_IS_TOGGLE_BUTTON(inUserData));
+
+	settings=XFDASHBOARD_HOT_CORNER_SETTINGS(inObject);
+	widget=GTK_TOGGLE_BUTTON(inUserData);
 
 	/* Get new value from settings */
-	value=xfdashboard_hot_corner_settings_get_primary_monitor_only(inMapping->settings);
+	value=xfdashboard_hot_corner_settings_get_primary_monitor_only(settings);
 
 	/* Set new value at widget */
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(inMapping->widget), value);
+	gtk_toggle_button_set_active(widget, value);
 }
 
+/* A widget is going to be destroyed */
+static void _plugin_on_widget_value_destroy(GtkWidget *inWidget,
+											gpointer inUserData)
+{
+	XfdashboardHotCornerSettings	*settings;
+	guint							signalID;
+
+	g_return_if_fail(GTK_IS_WIDGET(inWidget));
+	g_return_if_fail(inUserData);
+
+	signalID=GPOINTER_TO_UINT(inUserData);
+
+	/* Disconnect signal from setting as the widget where to update
+	 * the updated settings value at will be destroyed. So it will
+	 * not exist anymore when the signal handler is called.
+	 */
+	settings=xfdashboard_hot_corner_settings_new();
+	g_signal_handler_disconnect(settings, signalID);
+	g_object_unref(settings);
+}
+
+/* Connect signals and bind to widget */
+static void _plugin_configure_setup_widget(GtkWidget *inWidget,
+											XfdashboardHotCornerSettings *inSettings,
+											const gchar *inProperty,
+											GCallback inCallback)
+{
+	gchar							*signalName;
+	guint							signalID;
+
+	g_return_if_fail(GTK_IS_WIDGET(inWidget));
+	g_return_if_fail(XFDASHBOARD_IS_HOT_CORNER_SETTINGS(inSettings));
+	g_return_if_fail(inProperty && *inProperty);
+	g_return_if_fail(inCallback);
+
+	/* Connect signal to get notified if value at settings changed.
+	 * We connect to "destroy" signal of widget to release the signal handler
+	 * on settings object which will survive and will try to work on the
+	 * widget just being destroyed.
+	 */
+	signalName=g_strdup_printf("notify::%s", inProperty);
+	signalID=g_signal_connect(inSettings,
+								signalName,
+								inCallback,
+								inWidget);
+
+	g_signal_connect(inWidget,
+						"destroy",
+						G_CALLBACK(_plugin_on_widget_value_destroy),
+						GUINT_TO_POINTER(signalID));
+
+	/* Release allocated resources */
+	if(signalName) g_free(signalName);
+}
 
 /* Plugin configuration function */
 static GObject* plugin_configure(XfdashboardPlugin *self, gpointer inUserData)
@@ -320,7 +307,6 @@ static GObject* plugin_configure(XfdashboardPlugin *self, gpointer inUserData)
 	GtkWidget						*widgetLabel;
 	GtkWidget						*widgetValue;
 	XfdashboardHotCornerSettings	*settings;
-	PluginWidgetSettingsMap			*mapping;
 	GtkListStore					*listModel;
 	GtkTreeIter						modelIter;
 	GEnumClass						*enumClass;
@@ -341,14 +327,14 @@ static GObject* plugin_configure(XfdashboardPlugin *self, gpointer inUserData)
 	gtk_grid_attach(GTK_GRID(layout), widgetLabel, 0, 0, 1, 1);
 
 	widgetValue=gtk_combo_box_new();
-	mapping=_plugin_widget_settings_map_bind(widgetValue,
-												settings,
-												"activation-corner",
-												G_CALLBACK(_plugin_on_corner_settings_value_changed));
+	_plugin_configure_setup_widget(widgetValue,
+										settings,
+										"activation-corner",
+										G_CALLBACK(_plugin_on_corner_settings_value_changed));
 	g_signal_connect(widgetValue,
 						"changed",
 						G_CALLBACK(_plugin_on_corner_widget_value_changed),
-						mapping);
+						NULL);
 	gtk_grid_attach_next_to(GTK_GRID(layout), widgetValue, widgetLabel, GTK_POS_RIGHT, 1, 1);
 
 	listModel=gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
@@ -369,7 +355,7 @@ static GObject* plugin_configure(XfdashboardPlugin *self, gpointer inUserData)
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(widgetValue), renderer, TRUE);
 	gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(widgetValue), renderer, "text", 0);
 
-	_plugin_on_corner_settings_value_changed(mapping);
+	_plugin_on_corner_settings_value_changed(G_OBJECT(settings), NULL, widgetValue);
 
 	/* Add widget to choose activation radius */
 	widgetLabel=gtk_label_new(_("Radius of activation corner:"));
@@ -377,14 +363,14 @@ static GObject* plugin_configure(XfdashboardPlugin *self, gpointer inUserData)
 	gtk_grid_attach(GTK_GRID(layout), widgetLabel, 0, 1, 1, 1);
 
 	widgetValue=gtk_spin_button_new_with_range(1.0, 999.0, 1.0);
-	mapping=_plugin_widget_settings_map_bind(widgetValue,
-												settings,
-												"activation-radius",
-												G_CALLBACK(_plugin_on_radius_settings_value_changed));
+	_plugin_configure_setup_widget(widgetValue,
+										settings,
+										"activation-radius",
+										G_CALLBACK(_plugin_on_radius_settings_value_changed));
 	g_signal_connect(widgetValue,
 						"value-changed",
 						G_CALLBACK(_plugin_on_radius_widget_value_changed),
-						mapping);
+						NULL);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgetValue),
 								xfdashboard_hot_corner_settings_get_activation_radius(settings));
 	gtk_grid_attach_next_to(GTK_GRID(layout), widgetValue, widgetLabel, GTK_POS_RIGHT, 1, 1);
@@ -395,14 +381,14 @@ static GObject* plugin_configure(XfdashboardPlugin *self, gpointer inUserData)
 	gtk_grid_attach(GTK_GRID(layout), widgetLabel, 0, 2, 1, 1);
 
 	widgetValue=gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 100.0, 10000.0, 100.0);
-	mapping=_plugin_widget_settings_map_bind(widgetValue,
-												settings,
-												"activation-duration",
-												G_CALLBACK(_plugin_on_duration_settings_value_changed));
+	_plugin_configure_setup_widget(widgetValue,
+										settings,
+										"activation-duration",
+										G_CALLBACK(_plugin_on_duration_settings_value_changed));
 	g_signal_connect(widgetValue,
 						"value-changed",
 						G_CALLBACK(_plugin_on_duration_widget_value_changed),
-						mapping);
+						NULL);
 	g_signal_connect(widgetValue,
 						"format-value",
 						G_CALLBACK(_plugin_on_duration_settings_format_value),
@@ -413,14 +399,14 @@ static GObject* plugin_configure(XfdashboardPlugin *self, gpointer inUserData)
 
 	/* Add widget to limit checks to primary monitor only or to all monitors */
 	widgetValue=gtk_check_button_new_with_label(_("Primary monitor only"));
-	mapping=_plugin_widget_settings_map_bind(widgetValue,
-												settings,
-												"primary-monitor-only",
-												G_CALLBACK(_plugin_on_primary_monitor_only_settings_value_changed));
+	_plugin_configure_setup_widget(widgetValue,
+										settings,
+										"primary-monitor-only",
+										G_CALLBACK(_plugin_on_primary_monitor_only_settings_value_changed));
 	g_signal_connect(widgetValue,
 						"toggled",
 						G_CALLBACK(_plugin_on_primary_monitor_only_widget_value_changed),
-						mapping);
+						NULL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgetValue),
 								xfdashboard_hot_corner_settings_get_primary_monitor_only(settings));
 	gtk_grid_attach(GTK_GRID(layout), widgetValue, 0, 3, 2, 1);
@@ -462,17 +448,18 @@ G_MODULE_EXPORT void plugin_init(XfdashboardPlugin *self)
 	/* Set up localization */
 	xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
+	/* Register GObject types of this plugin */
+	XFDASHBOARD_REGISTER_PLUGIN_TYPE(self, xfdashboard_hot_corner);
+	XFDASHBOARD_REGISTER_PLUGIN_TYPE(self, xfdashboard_hot_corner_settings);
+
 	/* Set plugin info */
 	xfdashboard_plugin_set_info(self,
 								"name", _("Hot corner"),
 								"description", _("Activates xfdashboard when pointer is moved to a configured corner of monitor"),
 								"author", "Stephan Haller <nomad@froevel.de>",
+								"settings", xfdashboard_hot_corner_settings_new(),
 								NULL);
 
-	/* Register GObject types of this plugin */
-	XFDASHBOARD_REGISTER_PLUGIN_TYPE(self, xfdashboard_hot_corner);
-	XFDASHBOARD_REGISTER_PLUGIN_TYPE(self, xfdashboard_hot_corner_settings);
-
 	/* Connect plugin action handlers */
 	g_signal_connect(self, "enable", G_CALLBACK(plugin_enable), NULL);
 	g_signal_connect(self, "disable", G_CALLBACK(plugin_disable), NULL);
